"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

/**
 * Applies a bitwise NAND to the contents of two buffers. Returns a new buffer.
 *
 * @example
 * bitwise.buffer.nand(buffer1, buffer2, false) => Buffer(buffer1 NAND buffer2)
 *
 * @param {Buffer} buffer1 first buffer
 * @param {Buffer} buffer2 second buffer
 * @param {Boolean} isLooping loop through first buffer
 * @return {Buffer} buffer1 NAND buffer2
 */
var _default = function _default(buffer1, buffer2) {
  var isLooping = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  var length = isLooping ? buffer2.length : buffer1.length;
  var result = Buffer.alloc(length);

  for (var i = 0; i < length; i++) {
    var j = isLooping ? i % buffer1.length : i;
    result[i] = ~(buffer1[j] & buffer2[i]);
  }

  return result;
};

exports.default = _default;